#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .simulation_reports import simulation_reports
from .report_menu import report_menu
class report(Group):
    """
    'report' child.
    """

    fluent_name = "report"

    child_names = \
        ['simulation_reports', 'report_menu']

    simulation_reports: simulation_reports = simulation_reports
    """
    simulation_reports child of report.
    """
    report_menu: report_menu = report_menu
    """
    report_menu child of report.
    """



"""Module for events management."""
from functools import partial
import itertools
import threading
from typing import Callable, List

from ansys.api.fluent.v0 import events_pb2 as EventsProtoModule


class EventsManager:
    """Manages server-side events.

    This class allows the client to register and unregister callbacks with server events.

    Parameters
    ----------
    session_id : str
        Session ID.
    service :
        Event streaming service.

    Attributes
    ----------
    events_list : List[str]
        List of supported events.
    """

    def __init__(self, session_id: str, service):
        self._session_id: str = session_id
        self._events_service = service
        self._events_to_callbacks_map: dict = {}
        self._id_iter = itertools.count()
        self._lock: threading.Lock = threading.Lock()
        self._events_thread = None
        self._events_list: List[str] = [
            attr for attr in dir(EventsProtoModule) if attr.endswith("Event")
        ]

    def _listen_events(self, started_evt):
        responses = self._events_service.begin_streaming(started_evt)
        while True:
            try:
                response = next(responses)
                event_name = response.WhichOneof("as")
                with self._lock:
                    callbacks_map = self._events_to_callbacks_map.get(event_name, {})
                    for call_back in callbacks_map.values():
                        call_back(
                            session_id=self._session_id,
                            event_info=getattr(response, event_name),
                        )
            except StopIteration:
                break

    @property
    def events_list(self) -> List[str]:
        """Get a list of supported events.

        Parameters
        ----------
        None

        Returns
        -------
        List[str]
            List of supported events.
        """
        return self._events_list

    def register_callback(
        self, event_name: str, call_back: Callable, *args, **kwargs
    ) -> str:
        """Register the callback.

        Parameters
        ----------
        event_name : str
            Event name to register the callback to.

        call_back : Callable
            Callback to register.

        Returns
        -------
        str
            Registered callback ID.

        Raises
        ------
        RuntimeError
            If event name is not valid.
        """
        if not event_name in self.events_list:
            raise RuntimeError(f"{event_name} is not a valid event.")
        with self._lock:
            event_name = event_name.lower()
            id = f"{event_name}-{next(self._id_iter)}"
            callbacks_map = self._events_to_callbacks_map.get(event_name)
            if callbacks_map:
                callbacks_map.update({id: partial(call_back, *args, **kwargs)})
            else:
                self._events_to_callbacks_map[event_name] = {
                    id: partial(call_back, *args, **kwargs)
                }
            return id

    def unregister_callback(self, callback_id: str):
        """Unregister the callback.

        Parameters
        ----------
        callback_id : str
            ID of the registered callback.
        """
        with self._lock:
            for callbacks_map in self._events_to_callbacks_map.values():
                if callback_id in callbacks_map:
                    del callbacks_map[callback_id]

    def start(self):
        """Start EventsManager.

        Parameters
        ----------
        None

        Returns
        -------
        None
        """
        if self._events_thread is None:
            started_evt = threading.Event()
            self._events_thread: threading.Thread = threading.Thread(
                target=EventsManager._listen_events, args=(self, started_evt)
            )
            self._events_thread.start()
            started_evt.wait()

    def stop(self):
        """Stop EventsManager.

        Parameters
        ----------
        None

        Returns
        -------
        None
        """
        if self._events_thread:
            self._events_service.end_streaming()
            self._events_thread.join()
            self._events_thread = None



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class major_rule_line_color(String):
    """
    'major_rule_line_color' child.
    """

    fluent_name = "major-rule-line-color"




"""Module containing class encapsulating Fluent connection and the Base
Session."""
import importlib
import json
import os
from typing import Any
import warnings

import grpc

from ansys.fluent.core.fluent_connection import _FluentConnection
from ansys.fluent.core.services.datamodel_tui import TUIMenuGeneric
from ansys.fluent.core.session_base_meshing import _BaseMeshing
from ansys.fluent.core.session_shared import _CODEGEN_MSG_TUI
from ansys.fluent.core.solver.flobject import get_root as settings_get_root
from ansys.fluent.core.utils.fluent_version import get_version_for_filepath
from ansys.fluent.core.utils.logging import LOG

try:
    from ansys.fluent.core.solver.settings import root
except Exception:
    root = Any


def parse_server_info_file(filename: str):
    with open(filename, encoding="utf-8") as f:
        lines = f.readlines()
    ip_and_port = lines[0].strip().split(":")
    ip = ip_and_port[0]
    port = int(ip_and_port[1])
    password = lines[1].strip()
    return ip, port, password


class _BaseSession:
    """Instantiates a Fluent connection.

    Attributes
    ----------
    scheme_eval: SchemeEval
        Instance of SchemeEval on which Fluent's scheme code can be
        executed.

    Methods
    -------
    create_from_server_info_file(
        server_info_filepath, cleanup_on_exit, start_transcript
        )
        Create a Session instance from server-info file

    start_transcript()
        Start streaming of Fluent transcript

    stop_transcript()
        Stop streaming of Fluent transcript

    check_health()
        Check health of Fluent connection

    exit()
        Close the Fluent connection and exit Fluent.
    """

    def __init__(self, fluent_connection: _FluentConnection):
        self.fluent_connection = fluent_connection
        self.scheme_eval = self.fluent_connection.scheme_eval
        self._uploader = None

    @classmethod
    def create_from_server_info_file(
        cls,
        server_info_filepath: str,
        cleanup_on_exit: bool = True,
        start_transcript: bool = True,
    ):
        """Create a Session instance from server-info file.

        Parameters
        ----------
        server_info_filepath : str
            Path to server-info file written out by Fluent server
        cleanup_on_exit : bool, optional
            When True, the connected Fluent session will be shut down
            when PyFluent is exited or exit() is called on the session
            instance, by default True.
        start_transcript : bool, optional
            The Fluent transcript is started in the client only when
            start_transcript is True. It can be started and stopped
            subsequently via method calls on the Session object.
            Defaults to true.

        Returns
        -------
        Session
            Session instance
        """
        ip, port, password = parse_server_info_file(server_info_filepath)
        session = cls(
            fluent_connection=_FluentConnection(
                ip=ip,
                port=port,
                password=password,
                cleanup_on_exit=cleanup_on_exit,
                start_transcript=start_transcript,
            )
        )
        return session

    @property
    def id(self) -> str:
        """Return the session id."""
        return self.fluent_connection.id

    def start_transcript(self) -> None:
        """Start streaming of Fluent transcript."""
        self.fluent_connection.start_transcript()

    def stop_transcript(self) -> None:
        """Stop streaming of Fluent transcript."""
        self.fluent_connection.stop_transcript()

    def check_health(self) -> str:
        """Check health of Fluent connection."""
        return self.fluent_connection.check_health()

    def exit(self) -> None:
        """Close the Fluent connection and exit Fluent."""
        self.fluent_connection.exit()

    def execute_tui(self, command: str) -> None:
        """Executes a tui command."""
        self.fluent_connection.scheme_eval.scheme_eval(
            f'(tui-menu-execute {json.dumps(command)} "")'
        )

    def setup_python_console_in_tui(self):
        """Executes tui command to set up python console."""
        self.execute_tui("(api-setup-python-console)")

    def start_journal(self, file_path: str):
        """Executes tui command to start journal."""
        self.execute_tui(f'(api-start-python-journal "{file_path}")')

    def stop_journal(self, port_data=None):
        """Executes tui command to stop journal."""
        self.execute_tui(f"(api-stop-python-journal)")

    def get_fluent_version(self):
        """Gets and returns the fluent version."""
        return self.fluent_connection.get_fluent_version()

    def __enter__(self):
        """Close the Fluent connection and exit Fluent."""
        return self

    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any):
        self.fluent_connection.exit()

    def __getattr__(self, attr):
        return getattr(self.fluent_connection, attr)

    def __dir__(self):
        return sorted(
            set(
                list(self.__dict__.keys())
                + dir(type(self))
                + dir(self.fluent_connection)
            )
        )

    def _upload(self, file_path: str, remote_file_name: str = None):
        """Uploads a file on the server."""
        if not self._uploader:
            self._uploader = _Uploader(self.fluent_connection._remote_instance)
        return self._uploader.upload(file_path, remote_file_name)

    def _download(self, file_name: str, local_file_path: str = None):
        """Downloads a file from the server."""
        if not self._uploader:
            self._uploader = _Uploader(self.fluent_connection._remote_instance)
        return self._uploader.download(file_name, local_file_path)


class Session:
    """Instantiates a Fluent connection. This is a deprecated class. This has
    been replaced by the "_BaseSession" class to implement the new fluent
    launch modes.

    Attributes
    ----------
    scheme_eval: SchemeEval
        Instance of SchemeEval on which Fluent's scheme code can be
        executed.

    Methods
    -------
    create_from_server_info_file(
        server_info_filepath, cleanup_on_exit, start_transcript
        )
        Create a Session instance from server-info file

    start_transcript()
        Start streaming of Fluent transcript

    stop_transcript()
        Stop streaming of Fluent transcript

    check_health()
        Check health of Fluent connection

    exit()
        Close the Fluent connection and exit Fluent.
    """

    def __init__(
        self,
        ip: str = None,
        port: int = None,
        password: str = None,
        channel: grpc.Channel = None,
        cleanup_on_exit: bool = True,
        start_transcript: bool = True,
        remote_instance=None,
        fluent_connection=None,
    ):
        warnings.warn("Please use the new fluent launch modes", DeprecationWarning)
        if not fluent_connection:
            self.fluent_connection = _FluentConnection(
                ip=ip,
                port=port,
                password=password,
                channel=channel,
                cleanup_on_exit=cleanup_on_exit,
                start_transcript=start_transcript,
                remote_instance=remote_instance,
            )
        else:
            self.fluent_connection = fluent_connection

        self.scheme_eval = self.fluent_connection.scheme_eval

        self.meshing = _BaseMeshing(None, self.fluent_connection)

        self._datamodel_service_se = self.fluent_connection.datamodel_service_se
        self._datamodel_service_tui = self.fluent_connection.datamodel_service_tui
        self._settings_service = self.fluent_connection.settings_service

        self.solver = Session.Solver(self.fluent_connection)

        self._uploader = None

    @classmethod
    def create_from_server_info_file(
        cls,
        server_info_filepath: str,
        cleanup_on_exit: bool = True,
        start_transcript: bool = True,
    ) -> "Session":
        """Create a Session instance from server-info file.

        Parameters
        ----------
        server_info_filepath : str
            Path to server-info file written out by Fluent server
        cleanup_on_exit : bool, optional
            When True, the connected Fluent session will be shut down
            when PyFluent is exited or exit() is called on the session
            instance, by default True.
        start_transcript : bool, optional
            The Fluent transcript is started in the client only when
            start_transcript is True. It can be started and stopped
            subsequently via method calls on the Session object.
            Defaults to true.

        Returns
        -------
        Session
            Session instance
        """
        ip, port, password = parse_server_info_file(server_info_filepath)
        session = Session(
            fluent_connection=_FluentConnection(
                ip=ip,
                port=port,
                password=password,
                cleanup_on_exit=cleanup_on_exit,
                start_transcript=start_transcript,
            )
        )
        return session

    @property
    def id(self) -> str:
        """Return the session id."""
        return self.fluent_connection.id

    def start_transcript(self) -> None:
        """Start streaming of Fluent transcript."""
        self.fluent_connection.start_transcript()

    def stop_transcript(self) -> None:
        """Stop streaming of Fluent transcript."""
        self.fluent_connection.stop_transcript()

    def check_health(self) -> str:
        """Check health of Fluent connection."""
        return self.fluent_connection.check_health()

    def exit(self) -> None:
        """Close the Fluent connection and exit Fluent."""
        self.fluent_connection.exit()

    def __enter__(self):
        """Close the Fluent connection and exit Fluent."""
        return self

    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any):
        self.fluent_connection.exit()

    def __getattr__(self, attr):
        return getattr(self.fluent_connection, attr)

    def __dir__(self):
        return sorted(
            set(
                list(self.__dict__.keys())
                + dir(type(self))
                + dir(self.fluent_connection)
            )
        )

    def _upload(self, file_path: str, remote_file_name: str = None):
        """Uploads a file on the server."""
        if not self._uploader:
            self._uploader = _Uploader(self.fluent_connection._remote_instance)
        return self._uploader.upload(file_path, remote_file_name)

    def _download(self, file_name: str, local_file_path: str = None):
        """Downloads a file from the server."""
        if not self._uploader:
            self._uploader = _Uploader(self.fluent_connection._remote_instance)
        return self._uploader.download(file_name, local_file_path)

    class Solver:
        def __init__(self, fluent_connection: _FluentConnection):
            self._fluent_connection = fluent_connection
            self._tui_service = fluent_connection.datamodel_service_tui
            self._settings_service = fluent_connection.settings_service
            self._tui = None
            self._settings_root = None
            self._version = None

        def get_fluent_version(self):
            """Gets and returns the fluent version."""
            return self._fluent_connection.get_fluent_version()

        @property
        def version(self):
            if self._version is None:
                self._version = get_version_for_filepath(session=self)
            return self._version

        @property
        def tui(self):
            """Instance of ``main_menu`` on which Fluent's SolverTUI methods
            can be executed."""
            if self._tui is None:
                try:
                    tui_module = importlib.import_module(
                        f"ansys.fluent.core.solver.tui_{self.version}"
                    )
                    self._tui = tui_module.main_menu([], self._tui_service)
                except (ImportError, ModuleNotFoundError):
                    LOG.warning(_CODEGEN_MSG_TUI)
                    self._tui = TUIMenuGeneric([], self._tui_service)
            return self._tui

        @property
        def root(self):
            """root settings object."""
            if self._settings_root is None:
                self._settings_root = settings_get_root(
                    flproxy=self._settings_service, version=self.version
                )
            return self._settings_root


class _Uploader:
    """Instantiates a file uploader and downloader to have a seamless file
    reading / writing in the cloud particularly in Ansys lab . Here we are
    exposing upload and download methods on session objects. These would be no-
    ops if PyPIM is not configured or not authorized with the appropriate
    service. This will be used for internal purpose only.

    Attributes
    ----------
    pim_instance: PIM instance
        Instance of PIM which supports upload server services.

    file_service: Client instance
        Instance of Client which supports upload and download methods.

    Methods
    -------
    upload(
        file_path, remote_file_name
        )
        Upload a file to the server.

    download(
        file_name, local_file_path
        )
        Download a file from the server.
    """

    def __init__(self, pim_instance):
        self.pim_instance = pim_instance

        try:
            upload_server = self.pim_instance.services["http-simple-upload-server"]
        except AttributeError:
            LOG.error("PIM is not installed or not authorized.")
        except KeyError:
            self.file_service = None
        else:
            from simple_upload_server.client import Client

            self.file_service = Client(
                token="token", url=upload_server.uri, headers=upload_server.headers
            )

    def upload(self, file_path: str, remote_file_name: str = None):
        """Uploads a file on the server."""
        expanded_file_path = os.path.expandvars(file_path)
        upload_file_name = remote_file_name or os.path.basename(expanded_file_path)
        self.file_service.upload_file(expanded_file_path, upload_file_name)

    def download(self, file_name: str, local_file_path: str = None):
        """Downloads a file from the server."""
        if self.file_service.file_exist(file_name):
            self.file_service.download_file(file_name, local_file_path)
        else:
            raise FileNotFoundError("Remote file does not exist.")



#
# This is an auto-generated file.  DO NOT EDIT!
#

"""A package providing Fluent's Settings Objects in Python."""
from ansys.fluent.core.solver.flobject import *

SHASH = "fbc7a2cfad3c920088ca42369b1adadd9e7bc34146f3ac2529244f4303af1de6"
from .root import root


#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class physics_based_constraint(Boolean):
    """
    Include physics driven time-step constraints.
    """

    fluent_name = "physics-based-constraint?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class convert_to_managed(Boolean):
    """
    'convert_to_managed' child.
    """

    fluent_name = "convert-to-managed"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class correction_tolerance_child(Real):
    """
    'child_object_type' of correction_tolerance.
    """

    fluent_name = "child-object-type"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class times_step_periods(Integer):
    """
    'times_step_periods' child.
    """

    fluent_name = "times-step-periods"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .type_1 import type
from .frequency import frequency
from .interval_1 import interval
class single_session_coupling(Group):
    """
    'single_session_coupling' child.
    """

    fluent_name = "single-session-coupling"

    child_names = \
        ['type', 'frequency', 'interval']

    type: type = type
    """
    type child of single_session_coupling.
    """
    frequency: frequency = frequency
    """
    frequency child of single_session_coupling.
    """
    interval: interval = interval
    """
    interval child of single_session_coupling.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class mgrid_relative_to_thread(String):
    """
    'mgrid_relative_to_thread' child.
    """

    fluent_name = "mgrid-relative-to-thread"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .value import value
from .option_8 import option
from .var_class import var_class
class acentric_factor(Group):
    """
    'acentric_factor' child.
    """

    fluent_name = "acentric-factor"

    child_names = \
        ['value', 'option', 'var_class']

    value: value = value
    """
    value child of acentric_factor.
    """
    option: option = option
    """
    option child of acentric_factor.
    """
    var_class: var_class = var_class
    """
    var_class child of acentric_factor.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enabled_1 import enabled
from .beams import beams
from .statistics import statistics
from .sampling_iterations import sampling_iterations
from .index_of_refraction import index_of_refraction
class optics(Group):
    """
    Enter the optics model menu.
    """

    fluent_name = "optics"

    child_names = \
        ['enabled', 'beams', 'statistics', 'sampling_iterations',
         'index_of_refraction']

    enabled: enabled = enabled
    """
    enabled child of optics.
    """
    beams: beams = beams
    """
    beams child of optics.
    """
    statistics: statistics = statistics
    """
    statistics child of optics.
    """
    sampling_iterations: sampling_iterations = sampling_iterations
    """
    sampling_iterations child of optics.
    """
    index_of_refraction: index_of_refraction = index_of_refraction
    """
    index_of_refraction child of optics.
    """



"""Wrapper over the monitor grpc service of Fluent."""

from google.protobuf.json_format import MessageToDict
import grpc

from ansys.api.fluent.v0 import monitor_pb2 as MonitorModule
from ansys.api.fluent.v0 import monitor_pb2_grpc as MonitorGrpcModule


class MonitorsService:
    """Class wrapping the monitor gRPC service of Fluent."""

    def __init__(self, channel: grpc.Channel, metadata):
        self.__stub = MonitorGrpcModule.MonitorStub(channel)
        self.__metadata = metadata
        self._streams = None

    def get_monitors_info(self) -> dict:
        """Get monitors information.

        Parameters
        ----------
        None

        Returns
        -------
        dict
            Dictionary containing the monitors information.
        """
        monitors_info = {}
        request = MonitorModule.GetMonitorsRequest()
        response = self.__stub.GetMonitors(request, metadata=self.__metadata)
        for monitor_set in response.monitorset:
            monitor_info = MessageToDict(monitor_set)
            monitors_info[monitor_set.name] = monitor_info
        return monitors_info

    def begin_streaming(self, started_evt):
        """Begin monitor streaming from Fluent.

        Parameters
        ----------
        None

        Yields
        -------
        Monitor data
            Monitor data i.e monitor x and y values.
        """

        request = MonitorModule.StreamingRequest()
        self._streams = self.__stub.BeginStreaming(request, metadata=self.__metadata)
        started_evt.set()
        while True:
            try:
                yield next(self._streams)
            except Exception:
                break

    def end_streaming(self):
        """End monitor streaming from Fluent.

        Parameters
        ----------
        None

        Returns
        -------
        None
        """
        if self._streams and not self._streams.cancelled():
            self._streams.cancel()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .number_of_iterations_1 import number_of_iterations
class iterate(Command):
    """
    Perform a specified number of iterations.
    
    Parameters
    ----------
        number_of_iterations : int
            Set incremental number of time steps.
    
    """

    fluent_name = "iterate"

    argument_names = \
        ['number_of_iterations']

    number_of_iterations: number_of_iterations = number_of_iterations
    """
    number_of_iterations argument of iterate.
    """



"""Wrapper over the transcript grpc service of Fluent."""

from typing import Generator, List, Tuple

import grpc

from ansys.api.fluent.v0 import transcript_pb2 as TranscriptModule
from ansys.api.fluent.v0 import transcript_pb2_grpc as TranscriptGrpcModule


class TranscriptService:
    """Class wrapping the transcript gRPC service of Fluent.

    Methods
    -------
    begin_streaming
        Begin transcript streaming from Fluent.
    """

    def __init__(self, channel: grpc.Channel, metadata: List[Tuple[str, str]]):
        self.__stub = TranscriptGrpcModule.TranscriptStub(channel)
        self.__metadata = metadata
        self.__streams = None

    def begin_streaming(
        self,
    ) -> Generator[TranscriptModule.TranscriptResponse, None, None]:
        """Begin transcript streaming from Fluent.

        Yields
        ------
        str
            A transcript line
        """
        request = TranscriptModule.TranscriptRequest()
        self.__streams = self.__stub.BeginStreaming(request, metadata=self.__metadata)

        while True:
            try:
                yield next(self.__streams)
            except Exception:
                break

    def end_streaming(self) -> None:
        if self.__streams and not self.__streams.cancelled():
            self.__streams.cancel()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .user_defined_function import user_defined_function
from .option_8 import option
from .var_class import var_class
class density(Group):
    """
    'density' child.
    """

    fluent_name = "density"

    child_names = \
        ['user_defined_function', 'option', 'var_class']

    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of density.
    """
    option: option = option
    """
    option child of density.
    """
    var_class: var_class = var_class
    """
    var_class child of density.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class remove_stuck_particles(Boolean):
    """
    Enable/disable removal of particles that are stuck at edges or faces.
    """

    fluent_name = "remove-stuck-particles?"




"""Wrapper over the events gRPC service of Fluent."""

import grpc

from ansys.api.fluent.v0 import events_pb2 as EventsProtoModule
from ansys.api.fluent.v0 import events_pb2_grpc as EventsGrpcModule


class EventsService:
    """Class wrapping the events gRPC service of Fluent."""

    def __init__(self, channel: grpc.Channel, metadata):
        self.__stub = EventsGrpcModule.EventsStub(channel)
        self.__metadata = metadata
        self.__streams = None

    def begin_streaming(self, started_evt):
        """Begin events streaming from Fluent.

        Yields
        ------
        Event
        """
        request = EventsProtoModule.BeginStreamingRequest()
        self.__streams = self.__stub.BeginStreaming(request, metadata=self.__metadata)
        started_evt.set()
        while True:
            try:
                yield next(self.__streams)
            except Exception:
                break

    def end_streaming(self):
        """End events streaming from Fluent."""

        if self.__streams and not self.__streams.cancelled():
            self.__streams.cancel()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
from .profile_name import profile_name
from .field_name import field_name
from .udf import udf
class velocity_ratio(Group):
    """
    'velocity_ratio' child.
    """

    fluent_name = "velocity-ratio"

    child_names = \
        ['option', 'value', 'profile_name', 'field_name', 'udf']

    option: option = option
    """
    option child of velocity_ratio.
    """
    value: value = value
    """
    value child of velocity_ratio.
    """
    profile_name: profile_name = profile_name
    """
    profile_name child of velocity_ratio.
    """
    field_name: field_name = field_name
    """
    field_name child of velocity_ratio.
    """
    udf: udf = udf
    """
    udf child of velocity_ratio.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class set_maximum_dynamic_strength(Real):
    """
    Set maximum value of dynamic anti-diffusion strength.
    """

    fluent_name = "set-maximum-dynamic-strength"




"""Wrappers over FieldData gRPC service of Fluent."""

from enum import IntEnum
from functools import reduce
from typing import Dict, List, Optional, Tuple

import grpc
import numpy as np

from ansys.api.fluent.v0 import field_data_pb2 as FieldDataProtoModule
from ansys.api.fluent.v0 import field_data_pb2_grpc as FieldGrpcModule
from ansys.fluent.core.services.error_handler import catch_grpc_error
from ansys.fluent.core.services.interceptors import TracingInterceptor


class FieldDataService:
    def __init__(self, channel: grpc.Channel, metadata):
        tracing_interceptor = TracingInterceptor()
        intercept_channel = grpc.intercept_channel(channel, tracing_interceptor)
        self.__stub = FieldGrpcModule.FieldDataStub(intercept_channel)
        self.__metadata = metadata

    @catch_grpc_error
    def get_range(self, request):
        return self.__stub.GetRange(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_fields_info(self, request):
        return self.__stub.GetFieldsInfo(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_vector_fields_info(self, request):
        return self.__stub.GetVectorFieldsInfo(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_surfaces_info(self, request):
        return self.__stub.GetSurfacesInfo(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_fields(self, request):
        return self.__stub.GetFields(request, metadata=self.__metadata)


class FieldInfo:
    """Provides access to Fluent field information.

    Methods
    -------
    get_range(field: str, node_value: bool, surface_ids: List[int])
    -> List[float]
        Get the range (minimum and maximum values) of the field.

    get_fields_info(self) -> dict
        Get fields information (field name, domain, and section).

    get_vector_fields_info(self) -> dict
        Get vector fields information (vector of and components).

    get_surfaces_info(self) -> dict
        Get surfaces information (surface name, ID, and type).
    """

    def __init__(self, service: FieldDataService):
        self._service = service

    def get_range(
        self, field: str, node_value: bool = False, surface_ids: List[int] = []
    ) -> List[float]:
        request = FieldDataProtoModule.GetRangeRequest()
        request.fieldName = field
        request.nodeValue = node_value
        request.surfaceid.extend(
            [FieldDataProtoModule.SurfaceId(id=int(id)) for id in surface_ids]
        )
        response = self._service.get_range(request)
        return [response.minimum, response.maximum]

    def get_fields_info(self) -> dict:
        request = FieldDataProtoModule.GetFieldsInfoRequest()
        response = self._service.get_fields_info(request)
        return {
            field_info.solverName: {
                "display_name": field_info.displayName,
                "section": field_info.section,
                "domain": field_info.domain,
            }
            for field_info in response.fieldInfo
        }

    def get_vector_fields_info(self) -> dict:
        request = FieldDataProtoModule.GetVectorFieldsInfoRequest()
        response = self._service.get_vector_fields_info(request)
        return {
            vector_field_info.displayName: {
                "x-component": vector_field_info.xComponent,
                "y-component": vector_field_info.yComponent,
                "z-component": vector_field_info.zComponent,
            }
            for vector_field_info in response.vectorFieldInfo
        }

    def get_surfaces_info(self) -> dict:
        request = FieldDataProtoModule.GetSurfacesInfoResponse()
        response = self._service.get_surfaces_info(request)
        info = {
            surface_info.surfaceName: {
                "surface_id": [surf.id for surf in surface_info.surfaceId],
                "zone_id": surface_info.zoneId.id,
                "zone_type": surface_info.zoneType,
                "type": surface_info.type,
            }
            for surface_info in response.surfaceInfo
        }
        return info


class SurfaceDataType(IntEnum):
    """Provides surface data types."""

    Vertices = 1
    FacesConnectivity = 2
    FacesNormal = 3
    FacesCentroid = 4


class FieldData:
    """Provides access to Fluent field data on surfaces."""

    # data mapping
    _proto_field_type_to_np_data_type = {
        FieldDataProtoModule.FieldType.INT_ARRAY: np.int32,
        FieldDataProtoModule.FieldType.LONG_ARRAY: np.int64,
        FieldDataProtoModule.FieldType.FLOAT_ARRAY: np.float32,
        FieldDataProtoModule.FieldType.DOUBLE_ARRAY: np.float64,
    }
    _chunk_size = 256 * 1024
    _bytes_stream = True
    _payloadTags = {
        FieldDataProtoModule.PayloadTag.OVERSET_MESH: 1,
        FieldDataProtoModule.PayloadTag.ELEMENT_LOCATION: 2,
        FieldDataProtoModule.PayloadTag.NODE_LOCATION: 4,
        FieldDataProtoModule.PayloadTag.BOUNDARY_VALUES: 8,
    }

    def __init__(self, service: FieldDataService, field_info: FieldInfo):
        self._service = service
        self._field_info = field_info
        self._fields_request = None

    def _extract_fields(self, chunk_iterator):
        def _extract_field(field_datatype, field_size, chunk_iterator):
            if not chunk_iterator.is_active():
                raise RuntimeError("Chunk is Empty.")
            field_arr = np.empty(field_size, dtype=field_datatype)
            field_datatype_item_size = np.dtype(field_datatype).itemsize
            index = 0
            for chunk in chunk_iterator:
                if chunk.bytePayload:
                    count = min(
                        len(chunk.bytePayload) // field_datatype_item_size,
                        field_size - index,
                    )
                    field_arr[index : index + count] = np.frombuffer(
                        chunk.bytePayload, field_datatype, count=count
                    )
                    index += count
                    if index == field_size:
                        return field_arr
                else:
                    payload = (
                        chunk.floatPayload.payload
                        or chunk.intPayload.payload
                        or chunk.doublePayload.payload
                        or chunk.longPayload.payload
                    )
                    count = len(payload)
                    field_arr[index : index + count] = np.fromiter(
                        payload, dtype=field_datatype
                    )
                    index += count
                    if index == field_size:
                        return field_arr

        fields_data = {}
        for chunk in chunk_iterator:

            payload_info = chunk.payloadInfo
            field = _extract_field(
                self._proto_field_type_to_np_data_type[payload_info.fieldType],
                payload_info.fieldSize,
                chunk_iterator,
            )

            surface_id = payload_info.surfaceId
            payload_tag_id = reduce(
                lambda x, y: x | y,
                [self._payloadTags[tag] for tag in payload_info.payloadTag] or [0],
            )
            payload_data = fields_data.get(payload_tag_id)
            if not payload_data:
                payload_data = fields_data[payload_tag_id] = {}
            surface_data = payload_data.get(surface_id)
            if surface_data:
                surface_data.update({payload_info.fieldName: field})
            else:
                payload_data[surface_id] = {payload_info.fieldName: field}
        return fields_data

    def _get_fields_request(self):
        if not self._fields_request:
            self._fields_request = FieldDataProtoModule.GetFieldsRequest(
                provideBytesStream=self._bytes_stream,
                chunkSize=self._chunk_size,
            )
        return self._fields_request

    def get_surface_data(
        self,
        surface_name: str,
        data_type: SurfaceDataType,
        overset_mesh: Optional[bool] = False,
    ) -> Dict[int, np.array]:
        """Get surface data (vertices, faces connectivity, centroids, and
        normals).

        Parameters
        ----------
        surface_name : str
            Surface name for the surface data.
        data_type : SurfaceDataType
            SurfaceDataType Enum member.
        overset_mesh : bool, optional
            Whether to provide the overset method. The default is ``False``.

        Returns
        -------
        Dict[int, np.array]
            Dictionary containing a map of surface IDs to surface data.
        """
        surface_ids = self._field_info.get_surfaces_info()[surface_name]["surface_id"]
        self._get_fields_request().surfaceRequest.extend(
            [
                FieldDataProtoModule.SurfaceRequest(
                    surfaceId=surface_id,
                    oversetMesh=overset_mesh,
                    provideFaces=data_type == SurfaceDataType.FacesConnectivity,
                    provideVertices=data_type == SurfaceDataType.Vertices,
                    provideFacesCentroid=data_type == SurfaceDataType.FacesCentroid,
                    provideFacesNormal=data_type == SurfaceDataType.FacesNormal,
                )
                for surface_id in surface_ids
            ]
        )
        enum_to_field_name = {
            SurfaceDataType.FacesConnectivity: "faces",
            SurfaceDataType.Vertices: "vertices",
            SurfaceDataType.FacesCentroid: "centroid",
            SurfaceDataType.FacesNormal: "face-normal",
        }
        request = self._get_fields_request()
        self._fields_request = None
        tag_id = 0
        if overset_mesh:
            tag_id = self._payloadTags[FieldDataProtoModule.PayloadTag.OVERSET_MESH]
        fields = self._extract_fields(self._service.get_fields(request))[tag_id]
        return {
            surface_id: fields[surface_id][enum_to_field_name[data_type]]
            for surface_id in surface_ids
        }

    def get_scalar_field_data(
        self,
        surface_name: str,
        field_name: str,
        node_value: Optional[bool] = True,
        boundary_value: Optional[bool] = False,
    ) -> Dict[int, np.array]:
        """Get scalar field data on a surface.

        Parameters
        ----------
        surface_name : str
            Name of the surface.
        field_name : str
            Name of the scalar field.
        node_value : bool, optional
            Whether to provide data for the nodal location. The default is ``True``.
            When ``False``, data is provided for the element location.
        boundary_value : bool, optional
            Whether to provide slip velocity at the wall boundaries. The default is
            ``False``. When ``True``, no slip velocity is provided.

        Returns
        -------
        Dict[int, np.array]
            Dictionary containing a map of surface IDs to the scalar field.
        """
        surface_ids = self._field_info.get_surfaces_info()[surface_name]["surface_id"]
        self._get_fields_request().scalarFieldRequest.extend(
            [
                FieldDataProtoModule.ScalarFieldRequest(
                    surfaceId=surface_id,
                    scalarFieldName=field_name,
                    dataLocation=FieldDataProtoModule.DataLocation.Nodes
                    if node_value
                    else FieldDataProtoModule.DataLocation.Elements,
                    provideBoundaryValues=boundary_value,
                )
                for surface_id in surface_ids
            ]
        )
        request = self._get_fields_request()
        self._fields_request = None
        tag_id = 0
        if node_value:
            tag_id = self._payloadTags[FieldDataProtoModule.PayloadTag.NODE_LOCATION]
        else:
            tag_id = self._payloadTags[FieldDataProtoModule.PayloadTag.ELEMENT_LOCATION]
        if boundary_value:
            tag_id = (
                tag_id
                | self._payloadTags[FieldDataProtoModule.PayloadTag.BOUNDARY_VALUES]
            )
        fields = self._extract_fields(self._service.get_fields(request))[tag_id]
        return {
            surface_id: fields[surface_id][field_name] for surface_id in surface_ids
        }

    def get_vector_field_data(
        self,
        surface_name: str,
        vector_field: Optional[str] = "velocity",
    ) -> Dict[int, Tuple[np.array, float]]:
        """Get vector field data on a surface.

        Parameters
        ----------
        surface_name : str
            Name of the surface.
        vector_field : str, optional
            Name of the vector field.

        Returns
        -------
        Dict[int, Tuple[np.array, float]]
            Dictionary containing a map of surface IDs to a tuple of vector field and vector scale.
        """
        surface_ids = self._field_info.get_surfaces_info()[surface_name]["surface_id"]
        self._get_fields_request().vectorFieldRequest.extend(
            [
                FieldDataProtoModule.VectorFieldRequest(
                    surfaceId=surface_id,
                    vectorFieldName=vector_field,
                )
                for surface_id in surface_ids
            ]
        )
        request = self._get_fields_request()
        self._fields_request = None
        tag_id = 0
        fields = self._extract_fields(self._service.get_fields(request))
        return {
            surface_id: (
                fields[tag_id][surface_id][vector_field],
                fields[tag_id][surface_id]["vector-scale"][0],
            )
            for surface_id in surface_ids
        }

    def add_get_surfaces_request(
        self,
        surface_ids: List[int],
        overset_mesh: Optional[bool] = False,
        provide_vertices: Optional[bool] = True,
        provide_faces: Optional[bool] = True,
        provide_faces_centroid: Optional[bool] = False,
        provide_faces_normal: Optional[bool] = False,
    ) -> None:
        """Add request to get surface data (vertices, face connectivity,
        centroids, and normals).

        Parameters
        ----------
        surface_ids : List[int]
            List of surface IDS for the surface data.
        overset_mesh : bool, optional
            Whether to get the overset met. The default is ``False``.
        provide_vertices : bool, optional
            Whether to get node coordinates. The default is ``True``.
        provide_faces : bool, optional
            Whether to get face connectivity. The default is ``True``.
        provide_faces_centroid : bool, optional
            Whether to get face centroids. The default is ``False``.
        provide_faces_normal : bool, optional
            Whether to get faces normal. The default is ``False``

        Returns
        -------
        None
        """
        self._get_fields_request().surfaceRequest.extend(
            [
                FieldDataProtoModule.SurfaceRequest(
                    surfaceId=surface_id,
                    oversetMesh=overset_mesh,
                    provideFaces=provide_faces,
                    provideVertices=provide_vertices,
                    provideFacesCentroid=provide_faces_centroid,
                    provideFacesNormal=provide_faces_normal,
                )
                for surface_id in surface_ids
            ]
        )

    def add_get_scalar_fields_request(
        self,
        surface_ids: List[int],
        field_name: str,
        node_value: Optional[bool] = True,
        boundary_value: Optional[bool] = False,
    ) -> None:
        """Add request to get scalar field data on surfaces.

        Parameters
        ----------
        surface_ids : List[int]
            List of surface IDs for scalar field data.
        field_name : str
            Name of the scalar field.
        node_value : bool, optional
            Whether to provide the nodal location. The default is ``True``. If
            ``False``, the element location is provided.
        boundary_value : bool, optional
            Whether to provide the slip velocity at the wall boundaries. The default
            is ``False``. When ``True``, no slip velocity is provided.

        Returns
        -------
        None
        """
        self._get_fields_request().scalarFieldRequest.extend(
            [
                FieldDataProtoModule.ScalarFieldRequest(
                    surfaceId=surface_id,
                    scalarFieldName=field_name,
                    dataLocation=FieldDataProtoModule.DataLocation.Nodes
                    if node_value
                    else FieldDataProtoModule.DataLocation.Elements,
                    provideBoundaryValues=boundary_value,
                )
                for surface_id in surface_ids
            ]
        )

    def add_get_vector_fields_request(
        self,
        surface_ids: List[int],
        vector_field: Optional[str] = "velocity",
    ) -> None:
        """Add request to get vector field data on surfaces.

        Parameters
        ----------
        surface_ids : List[int]
            List of surface IDs for vector field data.
        vector_field : str, optional
            Name of the vector field.

        Returns
        -------
        None
        """
        self._get_fields_request().vectorFieldRequest.extend(
            [
                FieldDataProtoModule.VectorFieldRequest(
                    surfaceId=surface_id,
                    vectorFieldName=vector_field,
                )
                for surface_id in surface_ids
            ]
        )

    def get_fields(self) -> Dict[int, Dict[int, Dict[str, np.array]]]:
        """Get data for previously added requests.

        Returns
        -------
        Dict[int, Dict[int, Dict[str, np.array]]]
            Data is returned as dictionary of dictionaries in following structure:
            tag_id [int]-> surface_id [int] -> field_name [str] -> field_data[np.array]
        """
        request = self._get_fields_request()
        self._fields_request = None
        return self._extract_fields(self._service.get_fields(request))



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class adapt_mesh(Command):
    """
    Adapt the mesh based on set refinement/coarsening criterion.
    """

    fluent_name = "adapt-mesh"




"""Module containing class encapsulating Fluent connection.

**********PRESENTLY SAME AS MESHING WITHOUT THE SWITCH TO SOLVER***********
"""

from ansys.fluent.core.fluent_connection import _FluentConnection
from ansys.fluent.core.session import _BaseSession
from ansys.fluent.core.session_base_meshing import _BaseMeshing


class PureMeshing(_BaseSession):
    """Encapsulates a Fluent - Pure Meshing session connection.
    PureMeshing(_BaseSession) holds the top-level objects
    for meshing TUI and various meshing datamodel API calls.
    In pure-meshing mode, switch to solver is not available.
    Public attributes of this class or extracted from the _BaseMeshing
    class"""

    def __init__(self, fluent_connection: _FluentConnection):
        super(PureMeshing, self).__init__(fluent_connection=fluent_connection)

        self._base_meshing = _BaseMeshing(self.execute_tui, fluent_connection)

    @property
    def tui(self):
        """Instance of ``main_menu`` on which Fluent's SolverTUI methods can be
        executed."""
        return self._base_meshing.tui

    @property
    def meshing(self):
        """meshing datamodel root."""
        return self._base_meshing.meshing

    @property
    def workflow(self):
        """workflow datamodel root."""
        return self._base_meshing.workflow

    @property
    def PartManagement(self):
        """PartManagement datamodel root."""
        return self._base_meshing.PartManagement

    @property
    def PMFileManagement(self):
        """PMFileManagement datamodel root."""
        return self._base_meshing.PMFileManagement



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class enable_solid_time_step(Boolean):
    """
    Enable/Disable different time step size for solid zones?.
    """

    fluent_name = "enable-solid-time-step?"




"""Wrapper over the health check grpc service of Fluent."""

from enum import Enum
from typing import List, Tuple

import grpc

from ansys.api.fluent.v0 import health_pb2 as HealthCheckModule
from ansys.api.fluent.v0 import health_pb2_grpc as HealthCheckGrpcModule
from ansys.fluent.core.services.error_handler import catch_grpc_error


class HealthCheckService:
    """Class wrapping the health check gRPC service of Fluent.

    Methods
    -------
    check_health
        Check the health of the Fluent connection.
    """

    class Status(Enum):
        UNKNOWN = 0
        SERVING = 1
        NOT_SERVING = 2
        SERVICE_UNKNOWN = 3

    def __init__(self, channel: grpc.Channel, metadata: List[Tuple[str, str]]):
        self.__stub = HealthCheckGrpcModule.HealthStub(channel)
        self.__metadata = metadata

    @catch_grpc_error
    def check_health(self) -> str:
        """Check the health of the Fluent connection.

        Returns
        -------
        str
            "SERVING" or "NOT_SERVING"
        """
        request = HealthCheckModule.HealthCheckRequest()
        response = self.__stub.Check(request, metadata=self.__metadata)
        return HealthCheckService.Status(response.status).name



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class top_value_cells(Real):
    """
    'top_value_cells' child.
    """

    fluent_name = "top-value-cells"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class press_averaging_method(Integer):
    """
    'press_averaging_method' child.
    """

    fluent_name = "press-averaging-method"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .combustion_mixture import combustion_mixture
from .user_defined_function import user_defined_function
from .value import value
from .option_8 import option
from .var_class import var_class
class premix_laminar_speed(Group):
    """
    'premix_laminar_speed' child.
    """

    fluent_name = "premix-laminar-speed"

    child_names = \
        ['combustion_mixture', 'user_defined_function', 'value', 'option',
         'var_class']

    combustion_mixture: combustion_mixture = combustion_mixture
    """
    combustion_mixture child of premix_laminar_speed.
    """
    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of premix_laminar_speed.
    """
    value: value = value
    """
    value child of premix_laminar_speed.
    """
    option: option = option
    """
    option child of premix_laminar_speed.
    """
    var_class: var_class = var_class
    """
    var_class child of premix_laminar_speed.
    """



from ansys.fluent.core.services.datamodel_se import PyCallableStateObject


def _new_command_for_task(task, meshing):
    class NewCommandError(Exception):
        def __init__(self, task_name):
            super().__init__(f"Could not create command for meshing task {task_name}")

    task_cmd_name = task.CommandName()
    cmd_creator = getattr(meshing, task_cmd_name)
    if cmd_creator:
        new_cmd = cmd_creator.new()
        if new_cmd:
            return new_cmd
    raise NewCommandError(task._name_())


class MeshingWorkflow:
    class TaskContainer(PyCallableStateObject):
        def __init__(self, meshing):
            self._meshing_container = meshing
            self._task_container = meshing._workflow.TaskObject

        def __getitem__(self, name):
            return MeshingWorkflow.Task(self._meshing_container, name)

        def __getattr__(self, attr):
            return getattr(self._task_container, attr)

        def __dir__(self):
            return sorted(
                set(
                    list(self.__dict__.keys())
                    + dir(type(self))
                    + dir(self._task_container)
                )
            )

    class Task(PyCallableStateObject):
        def __init__(self, meshing, name):
            self.__dict__.update(
                dict(
                    _workflow=meshing._workflow,
                    _meshing=meshing._meshing,
                    _task=meshing._workflow.TaskObject[name],
                    _cmd=None,
                )
            )

        @property
        def CommandArguments(self):
            return self._refreshed_command()

        def _refreshed_command(self):
            task_arg_state = self.Arguments.get_state()
            cmd = self._command()
            if task_arg_state:
                cmd.update_dict(task_arg_state)
            return cmd

        def _command(self):
            if not self._cmd:
                self._cmd = _new_command_for_task(self._task, self._meshing)
            return self._cmd

        def __getattr__(self, attr):
            return getattr(self._task, attr)

        def __setattr__(self, attr, value):
            if attr in self.__dict__:
                self.__dict__[attr] = value
            else:
                setattr(self._task, attr, value)

        def __dir__(self):
            return sorted(
                set(list(self.__dict__.keys()) + dir(type(self)) + dir(self._task))
            )

    def __init__(self, workflow, meshing):
        self._workflow = workflow
        self._meshing = meshing

    def task(self, name):
        return MeshingWorkflow.Task(self, name)

    @property
    def TaskObject(self):
        return MeshingWorkflow.TaskContainer(self)

    def __getattr__(self, attr):
        return getattr(self._workflow, attr)

    def __dir__(self):
        return sorted(
            set(list(self.__dict__.keys()) + dir(type(self)) + dir(self._workflow))
        )

    def __call__(self):
        return self._workflow()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .user_defined_function import user_defined_function
from .mass_diffusivity import mass_diffusivity
from .lewis_number import lewis_number
from .option_8 import option
from .var_class import var_class
class mass_diffusivity(Group):
    """
    'mass_diffusivity' child.
    """

    fluent_name = "mass-diffusivity"

    child_names = \
        ['user_defined_function', 'mass_diffusivity', 'lewis_number',
         'option', 'var_class']

    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of mass_diffusivity.
    """
    mass_diffusivity: mass_diffusivity = mass_diffusivity
    """
    mass_diffusivity child of mass_diffusivity.
    """
    lewis_number: lewis_number = lewis_number
    """
    lewis_number child of mass_diffusivity.
    """
    option: option = option
    """
    option child of mass_diffusivity.
    """
    var_class: var_class = var_class
    """
    var_class child of mass_diffusivity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class check_reduction_wt(Boolean):
    """
    'check_reduction_wt' child.
    """

    fluent_name = "check-reduction-wt?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class unsteady_1st_order(Boolean):
    """
    Enable/disable first-order unsteady solution model.
    """

    fluent_name = "unsteady-1st-order?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .copy import copy
from .list_beam_parameters import list_beam_parameters
from .beams_child import beams_child

class beams(NamedObject[beams_child], _CreatableNamedObjectMixin[beams_child]):
    """
    Enter the optical beams menu.
    """

    fluent_name = "beams"

    command_names = \
        ['copy', 'list_beam_parameters']

    copy: copy = copy
    """
    copy command of beams.
    """
    list_beam_parameters: list_beam_parameters = list_beam_parameters
    """
    list_beam_parameters command of beams.
    """
    child_object_type: beams_child = beams_child
    """
    child_object_type of beams.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .moving_mesh_cfl_constraint import moving_mesh_cfl_constraint
from .physics_based_constraint import physics_based_constraint
from .time_scale_options import time_scale_options
from .verbosity_5 import verbosity
class multiphase_specific_time_constraints(Group):
    """
    'multiphase_specific_time_constraints' child.
    """

    fluent_name = "multiphase-specific-time-constraints"

    child_names = \
        ['moving_mesh_cfl_constraint', 'physics_based_constraint',
         'time_scale_options', 'verbosity']

    moving_mesh_cfl_constraint: moving_mesh_cfl_constraint = moving_mesh_cfl_constraint
    """
    moving_mesh_cfl_constraint child of multiphase_specific_time_constraints.
    """
    physics_based_constraint: physics_based_constraint = physics_based_constraint
    """
    physics_based_constraint child of multiphase_specific_time_constraints.
    """
    time_scale_options: time_scale_options = time_scale_options
    """
    time_scale_options child of multiphase_specific_time_constraints.
    """
    verbosity: verbosity = verbosity
    """
    verbosity child of multiphase_specific_time_constraints.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class index_of_refraction(Real):
    """
    Specify the model parameters of index of refraction.
    """

    fluent_name = "index-of-refraction"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .fmg_initialize import fmg_initialize
from .localized_turb_init import localized_turb_init
from .reference_frame_1 import reference_frame
from .fmg_options import fmg_options
from .set_hybrid_init_options import set_hybrid_init_options
from .patch import patch
from .standard_initialize import standard_initialize
from .hybrid_initialize import hybrid_initialize
from .dpm_reset import dpm_reset
from .lwf_reset import lwf_reset
from .init_flow_statistics import init_flow_statistics
from .init_acoustics_options import init_acoustics_options
class initialization(Group):
    """
    'initialization' child.
    """

    fluent_name = "initialization"

    child_names = \
        ['fmg_initialize', 'localized_turb_init', 'reference_frame',
         'fmg_options', 'set_hybrid_init_options', 'patch']

    fmg_initialize: fmg_initialize = fmg_initialize
    """
    fmg_initialize child of initialization.
    """
    localized_turb_init: localized_turb_init = localized_turb_init
    """
    localized_turb_init child of initialization.
    """
    reference_frame: reference_frame = reference_frame
    """
    reference_frame child of initialization.
    """
    fmg_options: fmg_options = fmg_options
    """
    fmg_options child of initialization.
    """
    set_hybrid_init_options: set_hybrid_init_options = set_hybrid_init_options
    """
    set_hybrid_init_options child of initialization.
    """
    patch: patch = patch
    """
    patch child of initialization.
    """
    command_names = \
        ['standard_initialize', 'hybrid_initialize', 'dpm_reset', 'lwf_reset',
         'init_flow_statistics', 'init_acoustics_options']

    standard_initialize: standard_initialize = standard_initialize
    """
    standard_initialize command of initialization.
    """
    hybrid_initialize: hybrid_initialize = hybrid_initialize
    """
    hybrid_initialize command of initialization.
    """
    dpm_reset: dpm_reset = dpm_reset
    """
    dpm_reset command of initialization.
    """
    lwf_reset: lwf_reset = lwf_reset
    """
    lwf_reset command of initialization.
    """
    init_flow_statistics: init_flow_statistics = init_flow_statistics
    """
    init_flow_statistics command of initialization.
    """
    init_acoustics_options: init_acoustics_options = init_acoustics_options
    """
    init_acoustics_options command of initialization.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class frequency_type(String):
    """
    Set the auto save frequency type to either time-step or crank-angle and set the corresponding frequency.
    """

    fluent_name = "frequency-type"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class maximum_refinement_level(Integer):
    """
    Set maximum level of refinement in the mesh.
    """

    fluent_name = "maximum-refinement-level"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .beam_name_1 import beam_name
class list_beam_parameters(Command):
    """
    List parameters of optical beam grid.
    
    Parameters
    ----------
        beam_name : str
            Choose the name for the optical beam to be listed.
    
    """

    fluent_name = "list-beam-parameters"

    argument_names = \
        ['beam_name']

    beam_name: beam_name = beam_name
    """
    beam_name argument of list_beam_parameters.
    """



import importlib

from ansys.fluent.core.fluent_connection import _FluentConnection
from ansys.fluent.core.meshing.meshing import Meshing
from ansys.fluent.core.meshing.workflow import MeshingWorkflow
from ansys.fluent.core.services.datamodel_se import PyMenuGeneric
from ansys.fluent.core.services.datamodel_tui import TUIMenuGeneric
from ansys.fluent.core.session_shared import _CODEGEN_MSG_DATAMODEL, _CODEGEN_MSG_TUI
from ansys.fluent.core.utils.fluent_version import get_version_for_filepath
from ansys.fluent.core.utils.logging import LOG


class _BaseMeshing:
    def __init__(self, session_execute_tui, fluent_connection: _FluentConnection):
        self._tui_service = fluent_connection.datamodel_service_tui
        self._se_service = fluent_connection.datamodel_service_se
        self._fluent_connection = fluent_connection
        self._tui = None
        self._meshing = None
        self._workflow = None
        self._part_management = None
        self._pm_file_management = None
        self._session_execute_tui = session_execute_tui
        self._version = None

    def get_fluent_version(self):
        """Gets and returns the fluent version."""
        return self._fluent_connection.get_fluent_version()

    @property
    def version(self):
        if self._version is None:
            self._version = get_version_for_filepath(session=self)
        return self._version

    @property
    def tui(self):
        """Instance of ``main_menu`` on which Fluent's SolverTUI methods can be
        executed."""
        if self._tui is None:
            try:
                tui_module = importlib.import_module(
                    f"ansys.fluent.core.meshing.tui_{self.version}"
                )
                self._tui = tui_module.main_menu([], self._tui_service)
            except (ImportError, ModuleNotFoundError):
                LOG.warning(_CODEGEN_MSG_TUI)
                self._tui = TUIMenuGeneric([], self._tui_service)
        return self._tui

    @property
    def _meshing_root(self):
        """meshing datamodel root."""
        try:
            meshing_module = importlib.import_module(
                f"ansys.fluent.core.datamodel_{self.version}.meshing"
            )
            meshing_root = meshing_module.Root(self._se_service, "meshing", [])
        except (ImportError, ModuleNotFoundError):
            LOG.warning(_CODEGEN_MSG_DATAMODEL)
            meshing_root = PyMenuGeneric(self._se_service, "meshing")
        return meshing_root

    @property
    def meshing(self):
        if self._meshing is None:
            self._meshing = Meshing(
                self._session_execute_tui,
                self._meshing_root,
                self.tui,
                self._fluent_connection,
            )
        return self._meshing

    @property
    def _workflow_se(self):
        """workflow datamodel root."""
        try:
            workflow_module = importlib.import_module(
                f"ansys.fluent.core.datamodel_{self.version}.workflow"
            )
            workflow_se = workflow_module.Root(self._se_service, "workflow", [])
        except (ImportError, ModuleNotFoundError):
            LOG.warning(_CODEGEN_MSG_DATAMODEL)
            workflow_se = PyMenuGeneric(self._se_service, "workflow")
        return workflow_se

    @property
    def workflow(self):
        if not self._workflow:
            self._workflow = MeshingWorkflow(self._workflow_se, self.meshing)
        return self._workflow

    @property
    def PartManagement(self):
        """PartManagement datamodel root."""
        if self._part_management is None:
            try:
                pm_module = importlib.import_module(
                    f"ansys.fluent.core.datamodel_{self.version}.PartManagement"
                )
                self._part_management = pm_module.Root(
                    self._se_service, "PartManagement", []
                )
            except (ImportError, ModuleNotFoundError):
                LOG.warning(_CODEGEN_MSG_DATAMODEL)
                self._part_management = PyMenuGeneric(
                    self._se_service, "PartManagement"
                )
        return self._part_management

    @property
    def PMFileManagement(self):
        """PMFileManagement datamodel root."""
        if self._pm_file_management is None:
            try:
                pmfm_module = importlib.import_module(
                    f"ansys.fluent.core.datamodel_{self.version}.PMFileManagement"
                )
                self._pm_file_management = pmfm_module.Root(
                    self._se_service, "PMFileManagement", []
                )
            except (ImportError, ModuleNotFoundError):
                LOG.warning(_CODEGEN_MSG_DATAMODEL)
                self._pm_file_management = PyMenuGeneric(
                    self._se_service, "PMFileManagement"
                )
        return self._pm_file_management



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .named_expressions_child import named_expressions_child

class named_expressions(NamedObject[named_expressions_child], _CreatableNamedObjectMixin[named_expressions_child]):
    """
    'named_expressions' child.
    """

    fluent_name = "named-expressions"

    child_object_type: named_expressions_child = named_expressions_child
    """
    child_object_type of named_expressions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class old_treatment_for_turbulent_diffusion(Boolean):
    """
    Old turbulent diffusion treatment is applicable to two phase flow when vapor is selected as a secondary phase.
    """

    fluent_name = "old-treatment-for-turbulent-diffusion?"




"""Module containing class encapsulating Fluent connection.

**********PRESENTLY SAME AS SOLVER WITH A SWITCH TO SOLVER***********
"""
import importlib

from ansys.fluent.core.fluent_connection import _FluentConnection
from ansys.fluent.core.session_solver import Solver
from ansys.fluent.core.utils.fluent_version import get_version_for_filepath


class SolverIcing(Solver):
    """Encapsulates a Fluent server for Icing session connection.

    SolverIcing(Session) holds the top-level objects for solver TUI,
    settings and icing datamodel objects calls.
    """

    def __init__(
        self,
        fluent_connection: _FluentConnection,
    ):
        super(SolverIcing, self).__init__(fluent_connection=fluent_connection)
        self._flserver_root = None
        self._version = None
        self._fluent_connection = fluent_connection

    def get_fluent_version(self):
        """Gets and returns the fluent version."""
        return self._fluent_connection.get_fluent_version()

    @property
    def version(self):
        if self._version is None:
            self._version = get_version_for_filepath(session=self)
        return self._version

    @property
    def _flserver(self):
        """root datamodel object."""
        if self._flserver_root is None:
            se = self.fluent_connection.datamodel_service_se
            dm_module = tui_module = importlib.import_module(
                f"ansys.fluent.core.datamodel_{self.version}.flicing"
            )
            self._flserver_root = dm_module.Root(se, "flserver", [])
        return self._flserver_root

    @property
    def icing(self):
        """instance of icing (Case.App) -> root datamodel object."""
        return self._flserver.Case.App
